# Guidelines

SDK guidelines for application developers, focusing on security. These
are a series of guidelines and examples for various aspects of
developing on and in the Apertis libraries and applications. They assume
a good level of competence with programming in C, and familiarity with
the underlying libraries Apertis uses, such as
[GLib](https://developer.gnome.org/glib/stable/). A good set of
introductory guidelines for using GLib and related libraries are the
[GNOME Programming
Guidelines](https://developer.gnome.org/programming-guidelines/unstable/).

To get started, skim each of the [General
guidelines](/#General_guidelines "wikilink") pages, each of which has a
summary at the top. Specific topics are covered in the [Specific
how-tos](/#Specific_how-tos "wikilink") section, which can be used more
like a reference manual.

The [external links](/#External_links "wikilink") point to further
resources, which can be quite comprehensive and are worth reading.

## General guidelines

  - [How to submit a patch in Apertis
    project](https://designs.apertis.org/latest/contribution-process.html)
  - [Packaging release
    workflow](/Guidelines/HowToReleasePackages "wikilink")
  - [Module
    setup](/Guidelines/Module_setup "wikilink")
  - [Licensing](https://designs.apertis.org/latest/license-applying.html)
  - [Coding
    conventions](https://designs.apertis.org/latest/coding_conventions.html)
  - [Upstream
    first](https://designs.apertis.org/latest/contribution-process.html#upstream-first-policy)
  - [Version control](/Guidelines/Version_control "wikilink")
  - [API design](/Guidelines/API_design "wikilink")
  - [API stability](/Guidelines/API_stability "wikilink")
  - [Memory management](/Guidelines/Memory_management "wikilink")
  - [Tooling](/Guidelines/Tooling "wikilink")
  - [Unit testing](/Guidelines/Unit_testing "wikilink")
  - [API documentation](/Guidelines/API_documentation "wikilink")
  - [Phabricator workflow](/Guidelines/Phabricator "wikilink")
  - [Code submission
    checklist](https://designs.apertis.org/latest/contribution-checklist.html)

## Specific how-tos

  - [How to develop on
    devices](/Guidelines/HowToDevelopOnDevices "wikilink")
  - [Add a new git repository](/Add_a_git_repository "wikilink")
  - [Package maintenance](/Package_maintenance "wikilink")
  - [JSON parsing](/Guidelines/JSON_parsing "wikilink")
  - [XML parsing](/Guidelines/XML_parsing "wikilink")
  - [GSettings](/Guidelines/GSettings "wikilink")
  - [D-Bus services](/Guidelines/D-Bus_services "wikilink")
  - [Introspection](/Guidelines/Introspection "wikilink")
  - [SQLite](/Guidelines/SQLite "wikilink")
  - [Tracker](/Guidelines/Tracker "wikilink")
  - [AppArmor](/Guidelines/AppArmor "wikilink")
  - [Threading](/Guidelines/Threading "wikilink")
  - [Filesystem access](/Guidelines/Filesystem_access "wikilink")
  - [Logging](/Guidelines/Logging "wikilink")
  - [Internationalization](/Guidelines/Internationalization "wikilink")
  - [Processes](/Guidelines/Processes "wikilink")
  - [Writing documentation in Mallard](/Mallard "wikilink")
  - [Writing test cases](/QA/Test_Cases_Guidelines "wikilink")
  - [Add linters to a project](/Add_linters_to_a_project "wikilink")
  - [Building, Patching And Maintaining The Apertis
    Kernel](/Guidelines/BuildingPatchingAndMaintainingTheApertisKernel "wikilink")

## External links

  - [CERT secure C coding
    guidelines](https://www.securecoding.cert.org/confluence/display/seccode/CERT+C+Coding+Standard)
  - [MISRA C coding guidelines
    overview](http://en.wikipedia.org/wiki/MISRA_C) (guidelines
    themselves are non-free)
  - [GNOME Programming
    Guidelines](https://developer.gnome.org/programming-guidelines/unstable/)
  - [Google C++
    guidelines](https://google-styleguide.googlecode.com/svn/trunk/cppguide.html#General_Naming_Rules)
    — useful general advice, but often not specific to GLib-style C, and
    sometimes contradictory to the GNOME Programming Guidelines, which
    are preferred