# Pre-installed images

When building pre-installed images, there are a couple needed
archifacts:

  - Operative system package (OSpack)
  - Hardware enablement package (HWpack)

Mixing both packages lead to creation of system images.

## Image Tools Installation

### Debian Jessie

1\. Install archive signing
key

` wget `<https://repositories.apertis.org/debian/pool/tools/c/collabora-obs-archive-keyring/collabora-obs-archive-keyring_0.5jessie1_all.deb>
` dpkg -i collabora-obs-archive-keyring_0.5jessie1_all.deb`

2\. Add the following repositories

` deb `<https://repositories.apertis.org/debian>` jessie tools`
` deb-src `<https://repositories.apertis.org/debian>` jessie tools`

3\. Install image-builder, linaro-image-tools and parted

` apt-get update && \`
` apt-get install image-builder \`
`                 linaro-image-tools=2012.09.1-1co42 \`
`                 python-linaro-image-tools=2012.09.1-1co42 \`
`                 libparted0debian1=2.3-11ubuntu1co3 \`
`                 parted=2.3-11ubuntu1co3 \`
`                 python-debian=0.1.25`

### Ubuntu 14.04

1\. Install archive signing
key

` wget `<https://repositories.apertis.org/ubuntu/pool/tools/c/collabora-obs-archive-keyring/collabora-obs-archive-keyring_0.5_all.deb>
` dpkg -i collabora-obs-archive-keyring_0.5_all.deb`

2\. Add the following repositories

` deb `<https://repositories.apertis.org/ubuntu>` trusty tools`
` deb-src `<https://repositories.apertis.org/ubuntu>` trusty tools`

3\. Install image-builder, linaro-image-tools and parted (you'll need to
enable universe Ubuntu repository component)

` apt-get update`
` apt-get install image-builder \`
`                 linaro-image-tools=2012.09.1-1co42 \`
`                 python-linaro-image-tools=2012.09.1-1co42 \`
`                 libparted0debian1=2.3-11ubuntu1co3 \`
`                 parted=2.3-11ubuntu1co3 \`
`                 python-debian=0.1.25`

## OSpack

OS packs are created with Debian native tool named
[live-build](https://build.collabora.co.uk/package/show?package=live-build&project=sac%3Ainfrastructure),
and those contain all Operative System generic software packages (in
other words, packages that are independent from target hardware) for the
runtime system.

Find available [live-build
documentation](http://live.debian.net/manual/stable/) and
[examples](http://live.debian.net/manual/stable/html/live-manual.en.html#772).
Refer to an example on [live-build configuration for Apertis ospack
generation](https://git.apertis.org/cgit/image-utils.git/tree/scripts/build/cb_ospack_config#n59).

## HWpack

HW packs are created using [Linaro Image
Tools](https://build.collabora.co.uk/package/show?package=linaro-image-tools&project=sac%3Ainfrastructure),
and those contain target hardware software components such as boot
loader, kernel and specific drivers.

  - [Hardware pack](/Hardware_pack "wikilink") creation guide

## Images

Once OSpack and HWpack are created, those can be mixed to create
flashable images with **linaro-media-create**. An example
    follows:

    TMPDIR="${CB_BUILDDIR:-.}"/image-build/${CB_BUILDSTAMP}/${suite}/${architecture}/${platform}/ \
     linaro-media-create \
       --hwpack-force-yes \
       --bootfs ext2 \
       --rootfs btrfs \
       --image-file "${IMAGE_FILE_NAME}".btrfs.img \
       --image-size "${IMAGE_SIZE}" \
       --hwpack "${HWPACK}" \
       --binary "${OSPACK}" \
       --dev "${IMAGE_DEVICE}"

  - Replace IMAGE_FILE_NAME with desired image file name.
  - IMAGE_SIZE to be allocated, it should match partition layout (i.e.
    8G)
  - HWPACK previously created
  - OSPACK previously created
  - IMAGE_DEVICE to create image for (i.e. i386, amd64-uefi, etc..)

### Image Post Processing

There are different operations to perform after image is created:

  - Set boot files
  - Set boot flags
  - Set factory image files
  - Scan for bugs
  - Convert to other virtualized formats
  - Generate zsync download file
  - Generate checksum file
  - Generate bmap-tools file
  - Generate split image for upgrading image
  - Generate master ostree to upgrade

Those can be studied in detail from looking at [image post process
code](https://git.apertis.org/cgit/image-utils.git/tree/scripts/build/cb_image_postprocess)

## Automating image builds

Using **live-build** and **linaro-image-tools**, everyone should be able
to generate working images from a build server. For automating such
tasks Jenkins or other task schedulers could be use to automate the
process. However for Apertis, there is a package that can be installed
along **image-utils**.

` apt-get install apertis-image-configs apertis-image-scripts`

  - **apertis-image-scripts** contains script to be used by debootstrap

<!-- end list -->

  - **apertis-image-configs** contains [Apertis image
    customizations](https://git.apertis.org/cgit/apertis-image-customization.git/)
    to be added to image build process (hwpack configurations,
    live-build pre-configuration, daily builds, etc...)

<!-- end list -->

  - [Apertis image
    builder](https://git.apertis.org/cgit/apertis-image-customization.git/tree/scripts/apertis-image-builder)
    contains the jobs to be executed by [daily cron
    task](https://git.apertis.org/cgit/apertis-image-customization.git/tree/debian/apertis-image-configs.cron.d)

# Trigger LAVA jobs

LAVA is the test automated framework which can run daily tests.

Prerequisites:

  - Configured LAVA service

1\. Use lqa tool, which can be browsed at [git
repositories](https://git.collabora.com/cgit/singularity/tools/lqa.git/).

2\. Install lqa from Apertis tools repository.

` apt-get update`
` apt-get install lqa`

3\. Add configuration files:

There are two main configuration files, one holding credentials
(configuration file) and another one holding build profiles (profile
file), grab the templates and accommodate them for your system:

  - [Profile
    file](https://git.collabora.com/cgit/singularity/tools/lqa.git/tree/examples/profiles.yaml)
      - Clone apertis test templates
        [repository](https://git.apertis.org/cgit/apertis-tests.git/) (a
        handy place to clone would be /etc/lqa/). Tests to be run are
        defined in the `templates/*.yaml` files, please review those and
        update substitution variables to accommodate your system. At
        least image parameter should be updated to point server where
        images are hosted.
      - Create this file at `/etc/lqa/apertis-validator-profiles.yaml`
      - Example configuration file used for Apertis 17.12

<!-- end list -->

``` yaml
main-profile:
  template-dir: apertis-tests/templates/
  templates: [ group-apparmor-tpl.yaml,
               group-common-tpl.yaml,
               group-folks-tpl.yaml,
               group-modules-tpl.yaml,
               sqlite-tpl.yaml ]
  variables:
    bootfstype: ext2
    imgpath: "daily/17.12/images"
    release_version: "17.12"
    fs: btrfs
    image_variant: collabora
    baseurl: "https://images.apertis.org"
    boot_method: grub
    boot_commands:
      - ramdisk
    needs_dtb: false
    device_type: minnowboard-turbot-E3826
    arch: amd64
    board: amd64-uefi
    visibility: public

profiles:
  - name: apertis-17.12-daily-minnowboard-max-minimal
    templates: [ group-apparmor-tpl.yaml,
                 group-common-tpl.yaml ]
    variables:
      pretty: "Minnowboard max using minimal image"
      image_type: minimal
  - name: apertis-17.12-daily-minnowboard-max-target
    variables:
      pretty: "Minnowboard max using target image"
      image_type: target
  - name: apertis-17.12-daily-minnowboard-max-development
    templates: [ group-common-tpl.yaml ]
    variables:
      pretty: "Minnowboard max using development image"
      image_type: development
  - name: apertis-17.12-daily-minnowboard-max-sdk
    templates: [ group-apparmor-tpl.yaml,
                 group-common-tpl.yaml,
                 group-folks-tpl.yaml,
                 group-modules-tpl.yaml,
                 group-sdk-tpl.yaml,
                 sqlite-tpl.yaml ]
    variables:
      pretty: "Minnowboard max using SDK image"
      image_type: sdk
  - name: apertis-17.12-daily-qemu-minimal
    templates: [ group-apparmor-tpl.yaml,
                 group-common-tpl.yaml ]
    variables:
      pretty: "QEMU using minimal image"
      image_type: minimal
      device_type: qemu
  - name: apertis-17.12-daily-qemu-target
    variables:
      pretty: "QEMU using target image"
      image_type: target
      device_type: qemu
  - name: apertis-17.12-daily-qemu-development
    templates: [ group-common-tpl.yaml ]
    variables:
      pretty: "QEMU using development image"
      image_type: development
      device_type: qemu
  - name: apertis-17.12-daily-qemu-sdk
    templates: [ group-apparmor-tpl.yaml,
                 group-common-tpl.yaml,
                 group-folks-tpl.yaml,
                 group-modules-tpl.yaml,
                 group-sdk-tpl.yaml,
                 sqlite-tpl.yaml ]
    variables:
      pretty: "QEMU using SDK image"
      image_type: sdk
      device_type: qemu
  - name: apertis-17.12-daily-arm64-generic-minimal
    templates: [ group-apparmor-tpl.yaml,
                 group-common-tpl.yaml ]
    variables:
      pretty: "ARM64 using minimal image"
      device_type: r8a7796-m3ulcb
      arch: arm64
      image_type: minimal
      board: arm64-generic
      boot_method: u-boot
      boot_commands:
        - run bootcmd_mmc0
      needs_dtb: true
```

  - [Configuration
    file](https://git.collabora.com/cgit/singularity/tools/lqa.git/tree/examples/lqa.yaml)
      - user: LAVA user
      - auth-token: Authentication token created from [LAVA
        API](https://lava.collabora.co.uk/api/tokens/)
      - server: server address including protocol (https)
      - Create this file at `/etc/lqa/apertis-validator-conf.yaml`

4\. Trigger jobs using lqa

` lqa -c /etc/lqa/apertis-validator-conf.yaml \`
`   --log-file /var/log/lqa-apertis-validator.log \`
`   submit \`
`     --all-profiles \`
`     -g /etc/lqa/apertis-validator-profiles.yaml \`
`     -t image_date:${timestamp}`

Replace timestamp, variant and version variables with the ones you want
to use with your image. Note that a *--wait* option can be used to wait
for analyse run.

5\. Extract results with lqa

**lqa** is able to analyse results, for that, you need to check
submitted jobs in the logs and ask analyse to provide you with a report:

` lqa -c /etc/lqa/singularity-validator-conf.yaml analyse ${JOB_IDS}`